@@ -1,5 +1,5 @@
 package Win32::Tracert;
-$Win32::Tracert::VERSION = '0.010';
+$Win32::Tracert::VERSION = '0.011';
 use strict;
 use warnings;
 
@@ -152,7 +152,7 @@ sub found{
         }
         else{
             #route to target undetermined
-            return undef;
+            return;
         }
     }
     else{
@@ -192,7 +192,7 @@ Win32::Tracert - Call Win32 tracert tool or parse Win32 tracert output
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
