@@ -1,5 +1,5 @@
 package Win32::Tracert::Parser;
-$Win32::Tracert::Parser::VERSION = '0.010';
+$Win32::Tracert::Parser::VERSION = '0.011';
 use strict;
 use warnings;
 
@@ -75,7 +75,7 @@ sub to_parse{
                           'PACKET3_RT' => $p3_rt,
                            };
             #Each data record is store to table in ascending order 
-            push $tracert_result->{"$ip_targeted"}->{'HOPS'}, $hop_data;
+            push @{$tracert_result->{"$ip_targeted"}->{'HOPS'}}, $hop_data;
             next LINE;
         }
         elsif ($curline =~ /^\s+\d+\s+(?:\*\s+){3}.*$/){
@@ -92,7 +92,7 @@ sub to_parse{
                           'PACKET3_RT' => $p3_rt,
                            };
             #Each data record is store to table in ascending order 
-            push $tracert_result->{"$ip_targeted"}->{'HOPS'}, $hop_data;
+            push @{$tracert_result->{"$ip_targeted"}->{'HOPS'}}, $hop_data;
             next LINE;
         }
         elsif ($curline =~ /^\s+\d+\s+\*\s+(?:\s+(?:\<1|\d+)\sms){2}.*$/){
@@ -124,7 +124,7 @@ sub to_parse{
                           'PACKET3_RT' => $p3_rt,
                            };
             #Each data record is store to table in ascending order 
-            push $tracert_result->{"$ip_targeted"}->{'HOPS'}, $hop_data;
+            push @{$tracert_result->{"$ip_targeted"}->{'HOPS'}}, $hop_data;
             next LINE;
         }
     }
@@ -145,7 +145,7 @@ Win32::Tracert::Parser - Parser object used by method B<to_trace> in Win32::Trac
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 AUTHOR
 
